pub enum FExp0<'a> {
Show 14 variants
App1(&'a FExp<'a>, &'a FExp<'a>),
App2(&'a FExp<'a>, &'a FExp<'a>, &'a FExp<'a>),
Var(&'a str),
Keyword(&'a str),
Tuple(Vec<'a, &'a FExp<'a>>),
Block(Vec<'a, &'a FExp<'a>>, Option<&'a FExp<'a>>),
Int(u64),
Float(f64),
Str(&'a str),
Prim(&'a str),
Special(&'a str),
Field(&'a str),
Tag(&'a str),
Error,
}Variants
App1(&'a FExp<'a>, &'a FExp<'a>)
f x => App1(f, x)
App2(&'a FExp<'a>, &'a FExp<'a>, &'a FExp<'a>)
`x + y => App2(f, x, y)
Var(&'a str)
a => Var("a")
Keyword(&'a str)
= => Keyword("=")
Tuple(Vec<'a, &'a FExp<'a>>)
[x, y] => Tuple([x, y])
Block(Vec<'a, &'a FExp<'a>>, Option<&'a FExp<'a>>)
{ x; y; } => Block([x, y], None)
{ x; y; e } => Block([x, y], Some(e))
Int(u64)
3 => Int(3)
Float(f64)
3.0 => Float(3.0)
Str(&'a str)
“hello world” => Str(“hello world”)
Prim(&'a str)
@foo => Prim("foo")
Special(&'a str)
%bar => Special("bar")
Field(&'a str)
.first => Field("first")
Tag(&'a str)
'some => Tag("some")
Error
It may be possible to keep parsing after an error; when this happens we insert an Error node into the syntax tree where the error happened